#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

#**************************************
# Required apache header
#**************************************

ApacheHeader()
{
	echo "Content-type: text/html"
	echo ""
}

#**************************************
# Send error messages to client
#**************************************

Send_NoDocument()
{
	ApacheHeader
	cat "$WEB_ROOT/index.html"
}

Send_InvalidDocument()
{
	export HYLAFAX_DocID="$FORM_DocID"
	ApacheHeader
	$WEB_ROOT/templates/invalid_document.tpl
}

Send_InvalidFaxNumber()
{
	export HYLAFAX_ErrorMsg="$1"
	local count=${#USER_FaxNumber[@]}
	if [ "$count" -gt 0 ]; then
		i=0
		while [ "$i" -lt "$count" ]; do
			if [ -z "${USER_ToContact[$i]}" ]; then
				history[$i]="${USER_FaxNumber[$i]}"
			else
				history[$i]="${USER_FaxNumber[$i]} - ${USER_ToContact[$i]}"
			fi
			i=`expr $i + 1`
		done
		# trick to export array (not yet supported by bash)
		export HYLAFAX_aHistory=$(printf '%q ' "${history[@]}")
	fi
	ApacheHeader
	$WEB_ROOT/templates/wiz_recipient_error.tpl
}

#**************************************
# global settings
#**************************************

# returned codes for CGI script
CGI_OK=0
CGI_ERROR=1

# read configuration file
PROC_CONFIG="/usr/bin/procconfig.sh"
CONFIG_FILE=/etc/cups/hylaFAX.conf
eval `$PROC_CONFIG "$CONFIG_FILE"`

WEB_ROOT=${CONFIG_WebRoot:-"/var/www/localhost/hylafax"}

#**************************************
# Process CGI data
#**************************************

PROC_CGI=${CONFIG_ProcCGI:-"/usr/bin/proccgi.sh"}
eval `$PROC_CGI $*`

# retrieve document ID which specify the postscript file to use
if [ -z "$FORM_DocID" ]; then
	Send_NoDocument
	exit $CGI_OK
fi
DOC_ID=`echo $FORM_DocID | tr -c '[:alnum:]' '[#*]' | cut -d'#' -f1 | tr '[A-Z]' '[a-z]'`
if [ -z "$DOC_ID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi
# build document file path
SPOOL_FOLDER=${CONFIG_SpoolFolder-"/var/spool/cups-hylafax/jobs"}
PS_FILE="$SPOOL_FOLDER/d$DOC_ID.ps"
# document still valid ?
if ! [ -f "$PS_FILE" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# read information from postscript file
#**************************************

PROC_PS=${CONFIG_ProcPostscript:-"/usr/bin/hylafax_procps.sh"}
eval `$PROC_PS "$PS_FILE"`

# doc ID stored in postscript file must be consistent with file name
if [ "$DOC_ID" != "$HYLAFAX_DocID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# OnValidate
#**************************************
if [ "$FORM_ValidateForm" = "1" ]; then

	# read user preference: either used to get selected fax or to display error web form
	PREF_FOLDER=${CONFIG_UserPrefFolder:-"/var/spool/cups-hylafax/etc"}
	PROC_PREF=${CONFIG_ProcUserPreference:-"/usr/bin/hylafax_procuser.sh"}
	PREF_FILE="${PREF_FOLDER}/${HYLAFAX_User:-any}.conf"
	eval `$PROC_PREF "$PREF_FILE"`

	if ( [ -n "$FORM_History" ] && [ "$FORM_History" -ge 0 ] && [ "$FORM_History" -lt ${#USER_FaxNumber[@]} ] ); then
		# get select fax number and cover page details from select history item
		HYLAFAX_FaxNumber="${USER_FaxNumber[$FORM_History]}"
		HYLAFAX_ToCompany="${USER_ToCompany[$FORM_History]}"
		HYLAFAX_ToContact="${USER_ToContact[$FORM_History]}"
		HYLAFAX_Subject="${USER_Subject[$FORM_History]}"
		HYLAFAX_Comments="${USER_Comments[$FORM_History]}"
	else
		HYLAFAX_FaxNumber="$FORM_FaxNumber"
		# remove spaces (not needed by Hylafax) but accepted in user entry
		fax=$(echo "$FORM_FaxNumber" | tr -d '[:space:]')

		if [ -z "$fax" ]; then
			Send_InvalidFaxNumber "You need to specify a fax number"
			exit $CGI_OK
		fi
		# number must be made of 11 digits only
		ALL_DIGIT=$(echo "$fax" | tr -d '[:digit:]')
		if [ -n "$ALL_DIGIT" ]; then
			Send_InvalidFaxNumber "Fax number can only include digits (and space)"
			exit $CGI_OK
		fi
		if [ ${#fax} -gt 11 ]; then
			Send_InvalidFaxNumber "Your fax number is too long (i.e. expected format: 0117 123 1234)"
			exit $CGI_OK
		fi
		if [ ${#fax} -lt 11 ]; then
			Send_InvalidFaxNumber "Your fax number is not complete (i.e. expected format: 0117 123 1234)"
			exit $CGI_OK
		fi
	fi
	#**************************************
	# update information in postscript file
	#**************************************

	UPDATE_PS=${CONFIG_UpdatePostscript:-"/usr/bin/hylafax_updateps.sh"}
	BUFFER=${CONFIG_Buffer:-"/usr/bin/buffer"}
	cat "$PS_FILE" | $UPDATE_PS | $BUFFER "$PS_FILE"
fi

#**************************************
# build web form
#**************************************

ApacheHeader
if [ "$HYLAFAX_UseCoverPage" -eq 1 ]; then
	$WEB_ROOT/templates/wiz_cover_page.tpl
else
	$WEB_ROOT/templates/wiz_finish.tpl
fi

exit $CGI_OK
