#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

#**************************************
# Required apache header
#**************************************

ApacheHeader()
{
	echo "Content-type: text/html"
	echo ""
}

#**************************************
# Send error messages to client
#**************************************

Send_NoDocument()
{
	ApacheHeader
	cat "$WEB_ROOT/index.html"
}

Send_InvalidDocument()
{
	export HYLAFAX_DocID="$FORM_DocID"
	ApacheHeader
	$WEB_ROOT/templates/invalid_document.tpl
}

#**************************************
# global settings
#**************************************

# returned codes for CGI script
CGI_OK=0
CGI_ERROR=1

# read configuration file
PROC_CONFIG="/usr/bin/procconfig.sh"
CONFIG_FILE=/etc/cups/hylaFAX.conf
eval `$PROC_CONFIG "$CONFIG_FILE"`

WEB_ROOT=${CONFIG_WebRoot-"/var/www/localhost/hylafax"}

PROC_CGI=${CONFIG_ProcCGI-"/usr/bin/proccgi.sh"}
PROC_PS=${CONFIG_ProcPostscript-"/usr/bin/hylafax_procps.sh"}
UPDATE_PS=${CONFIG_UpdatePostscript-"/usr/bin/hylafax_updateps.sh"}
BUFFER=${CONFIG_Buffer-"/usr/bin/buffer"}

#**************************************
# Process CGI data
#**************************************

eval `$PROC_CGI $*`

# retrieve document ID which specify the postscript file to use
if [ -z "$FORM_DocID" ]; then
	Send_NoDocument
	exit $CGI_OK
fi
DOC_ID=`echo $FORM_DocID | tr -c '[:alnum:]' '[#*]' | cut -d'#' -f1 | tr '[A-Z]' '[a-z]'`
if [ -z "$DOC_ID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi
# build document file path
SPOOL_FOLDER=${CONFIG_SpoolFolder-"/var/spool/cups-hylafax/jobs"}
PS_FILE="$SPOOL_FOLDER/d$DOC_ID.ps"
# document still valid ?
if ! [ -f "$PS_FILE" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# read information from postscript file
#**************************************

eval `$PROC_PS "$PS_FILE"`

# doc ID stored in postscript file must be consistent with file name
if [ "$DOC_ID" != "$HYLAFAX_DocID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# OnValidate
#**************************************
if [ "$FORM_ValidateForm" = "1" ]; then

	HYLAFAX_ToCompany="$FORM_ToCompany"
	HYLAFAX_ToContact="$FORM_ToContact"
	HYLAFAX_Subject="$FORM_Subject"
	HYLAFAX_Comments="$FORM_Comments"

	#**************************************
	# update information in postscript file
	#**************************************

	cat "$PS_FILE" | $UPDATE_PS | $BUFFER "$PS_FILE"
fi

#**************************************
# build web form
#**************************************

ApacheHeader
$WEB_ROOT/templates/wiz_finish.tpl

exit $CGI_OK
