#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

#**************************************
# Required apache header
#**************************************

ApacheHeader()
{
	echo "Content-type: text/html"
	echo ""
}

#**************************************
# Send default error messages to client
#**************************************

Send_NoDocument()
{
	ApacheHeader
	cat "$WEB_ROOT/index.html"
}

Send_InvalidDocument()
{
	export HYLAFAX_DocID="$FORM_DocID"
	ApacheHeader
	$WEB_ROOT/templates/invalid_document.tpl
}

#**************************************
# global settings
#**************************************

# returned codes for CGI script
CGI_OK=0

# read configuration file
PROC_CONFIG="/usr/bin/procconfig.sh"
CONFIG_FILE=/etc/cups/hylaFAX.conf
eval `$PROC_CONFIG "$CONFIG_FILE"`

WEB_ROOT=${CONFIG_WebRoot-"/var/www/localhost/hylafax"}

PROC_CGI=${CONFIG_ProcCGI-"/usr/bin/proccgi.sh"}
PROC_PS=${CONFIG_ProcPostscript-"/usr/bin/hylafax_procps.sh"}

#**************************************
# Process CGI data
#**************************************

eval `$PROC_CGI $*`

# retrieve document ID which specify the postscript file to use
if test -z "$FORM_DocID"; then
	Send_NoDocument
	exit $CGI_OK
fi
DOC_ID=`echo $FORM_DocID | tr -c '[:alnum:]' '[#*]' | cut -d'#' -f1 | tr '[A-Z]' '[a-z]'`
if test -z "$DOC_ID"; then
	Send_InvalidDocument
	exit $CGI_OK
fi
# build document file path
SPOOL_FOLDER=${CONFIG_SpoolFolder-"/var/spool/cups-hylafax/jobs"}
PS_FILE="$SPOOL_FOLDER/d$DOC_ID.ps"
# document still valid ?
if !(test -f "$PS_FILE"); then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# read information from postscript file
#**************************************

eval `$PROC_PS "$PS_FILE"`

# doc ID stored in postscript file must be consistent with file name
if test "$DOC_ID" != "$HYLAFAX_DocID"; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# build web form
#**************************************

ApacheHeader
$WEB_ROOT/templates/wiz_general.tpl

exit $CGI_OK
