#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

#**************************************
# Output required apache header
#**************************************

ApacheHeader()
{
	echo "Content-type: text/html"
	echo ""
}

#**************************************
# Send error messages to client
#**************************************

Send_NoDocument()
{
	ApacheHeader
	cat "$WEB_ROOT/index.html"
}

Send_InvalidDocument()
{
	export HYLAFAX_DocID="$FORM_DocID"
	ApacheHeader
	$WEB_ROOT/templates/invalid_document.tpl
}

#**************************************
# Emulate push front history database
#**************************************

History_PushFront()
{
	local count=${#USER_FaxNumber[@]}
	# empty history ?
	if [ "$count" -gt 0 ]; then
		if [ "$count" -gt "$HISTORY_MAX_SIZE" ]; then
			# history list size should only be 9 max. If not something is wrong so better clear all
			unset USER_FaxNumber
			unset USER_ToCompany
			unset USER_ToContact
			unset USER_Subject
			unset USER_Comments
		else
			local fax="$1"
			# new element already in front ?
			if [ "${USER_FaxNumber[0]}" != "$fax" ]; then
				# remove new fax number from history if defined
				local i=1
				while [ "$i" -lt "$count" ]; do
					[ "${USER_FaxNumber[$i]}" =  "$fax" ] && break
					i=`expr $i + 1`
				done
				# push everything to leave first element free (9 ele max)
				if [ "$i" -eq "$HISTORY_MAX_SIZE" ]; then
						i=`expr $i - 1`
				fi
				while [ "$i" -gt 0 ]; do
							local j=`expr $i - 1`
							USER_FaxNumber[$i]="${USER_FaxNumber[$j]}"
							USER_ToCompany[$i]="${USER_ToCompany[$j]}"
							USER_ToContact[$i]="${USER_ToContact[$j]}"
							USER_Subject[$i]="${USER_Subject[$j]}"
							USER_Comments[$i]="${USER_Comments[$j]}"
							i=`expr $i - 1`
				done
			fi
		fi
	fi
}

#**************************************
# global settings
#**************************************

# returned codes for CGI script
CGI_OK=0
CGI_ERROR=1

# read configuration file
PROC_CONFIG=/usr/bin/procconfig.sh
CONFIG_FILE=/etc/cups/hylaFAX.conf
eval `$PROC_CONFIG "$CONFIG_FILE"`

WEB_ROOT=${CONFIG_WebRoot-"/var/www/localhost/hylafax"}

HISTORY_MAX_SIZE=9

#**************************************
# Process CGI data
#**************************************

PROC_CGI=${CONFIG_ProcCGI-"/usr/bin/proccgi.sh"}
eval `$PROC_CGI $*`

# retrieve document ID which specify the postscript file to use
if [ -z "$FORM_DocID" ]; then
	Send_NoDocument
	exit $CGI_OK
fi
DOC_ID=`echo $FORM_DocID | tr -c '[:alnum:]' '[#*]' | cut -d'#' -f1 | tr '[A-Z]' '[a-z]'`
if [ -z "$DOC_ID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi
# build document file path
SPOOL_FOLDER=${CONFIG_SpoolFolder-"/var/spool/cups-hylafax/jobs"}
PS_FILE="$SPOOL_FOLDER/d$DOC_ID.ps"
# document still valid ?
if ! [ -f "$PS_FILE" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# read information from postscript file
#**************************************

PROC_PS=${CONFIG_ProcPostscript-"/usr/bin/hylafax_procps.sh"}
eval `$PROC_PS "$PS_FILE"`

# doc ID stored in postscript file must be consistent with file name
if [ "$DOC_ID" != "$HYLAFAX_DocID" ]; then
	Send_InvalidDocument
	exit $CGI_OK
fi

#**************************************
# send fax
#**************************************

/usr/bin/sudo /usr/bin/hylafax_sendps.sh "$PS_FILE"
rm -f "$PS_FILE"

#**************************************
# save user preferences
#**************************************

PREF_FOLDER=${CONFIG_UserPrefFolder:-"/var/spool/cups-hylafax/etc"}
PROC_PREF=${CONFIG_ProcUserPreference:-"/usr/bin/hylafax_procuser.sh"}
PREF_FILE="${PREF_FOLDER}/${HYLAFAX_User:-any}.conf"
eval `$PROC_PREF "$PREF_FILE"`

History_PushFront "$HYLAFAX_FaxNumber"
# first element is user last entry
USER_FaxNumber[0]="$HYLAFAX_FaxNumber"
USER_ToCompany[0]="$HYLAFAX_ToCompany"
USER_ToContact[0]="$HYLAFAX_ToContact"
USER_Subject[0]="$HYLAFAX_Subject"
USER_Comments[0]="$HYLAFAX_Comments"

(
	echo "NotifySuccess=$HYLAFAX_NotifySuccess"
	echo "UseCoverPage=$HYLAFAX_UseCoverPage"
	count=${#USER_FaxNumber[@]}
	i=0
	while [ "$i" -lt "$count" ]; do
		echo "FaxNumber[$i]=${USER_FaxNumber[$i]}"
		echo "ToCompany[$i]=${USER_ToCompany[$i]}"
		echo "ToContact[$i]=${USER_ToContact[$i]}"
		echo "Subject[$i]=${USER_Subject[$i]}"
		echo "Comments[$i]=${USER_Comments[$i]}"
		i=`expr $i + 1`
	done
) > "$PREF_FILE"

#**************************************
# build web form
#**************************************

ApacheHeader
$WEB_ROOT/templates/wiz_sent.tpl

exit $CGI_OK
