#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

function to_html()
{
	local s="$@"
	s=${s//&/&amp;}
	s=${s//\'/&apos;}
	s=${s//\"/&quot;}
	s=${s//</&lt;}
	s=${s//>/&gt;}
	echo $s
}

DOC_ID=`to_html $HYLAFAX_DocID`
JOB_ID=`to_html $HYLAFAX_JobID`
TITLE=`to_html $HYLAFAX_Title`
FAX_NUMBER=`to_html $HYLAFAX_FaxNumber`
if [ "$HYLAFAX_NotifySuccess" -ne 1 ]; then
	NOTIFY_SUCCESS="un"
fi
if [ "$HYLAFAX_UseCoverPage" -eq 1 ]; then
	COMPANY=`to_html $HYLAFAX_ToCompany`
	CONTACT=`to_html $HYLAFAX_ToContact`
	SUBJECT=`to_html $HYLAFAX_Subject`
	PREVIOUS_PAGE="cover_page"
else
	USE_COVER_PAGE="un"
	COMPANY="n/a"
	CONTACT="n/a"
	SUBJECT="n/a"
	PREVIOUS_PAGE="recipient"
fi

cat << __HYLAFAX_HTML_EOF__
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
	<head>
		<title>Send Fax Wizard - Finish</title>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
		<link rel="stylesheet" type="text/css" href="/hylafax/templates/wiz.css" />
	</head>
	<body>
		<table>
			<tr><td>
				<table class="caption">
					<tr valign="center">
						<td valign="center">
							<h1 class="caption">Send Fax Wizard</h1>
						</td>
						<td align="left" valign="center">
							<img src="/hylafax/images/fax.gif" align="right">
						</td>
					</tr>
				</table>
                <hr>
			</td></tr>
			<tr><td>
                <table>
                    <tr>
                        <td><p class="doc_info_label">Job ID</p></td>
                        <td><p class="doc_info_data">$JOB_ID</p></td>
                    </tr>
                    <tr>
                        <td><p class="doc_info_label">Document:</p></td>
                        <td><p class="doc_info_data">$TITLE</p></td>
                    </tr>
                </table>
				<hr>
			</td></tr>
			<tr><td>
				<form action="/cgi-bin/wiz_send.sh" method="post">
					<input type="hidden" name="DocID" value="$DOC_ID">
					<h3 class="caption">Completing the Send Fax Wizard</h3>
					<p>You have successfully setup the fax as follows:</p>
					<p>Fax number: $FAX_NUMBER</p>
					<ul>
						<li class="${NOTIFY_SUCCESS}checked_item">Notify by email on success.</li>
						<li class="${USE_COVER_PAGE}checked_item">Use cover page.
						<ul>
							<li class="square_item">Company: $COMPANY</li>
							<li class="square_item">Contact: $CONTACT</li>
							<li class="square_item">Subject: $SUBJECT</li>
						</ul>
						</li>
					</ul>
					<p>To send your fax click Finish.</p>
                    			<hr>
					<table width="100%">
						<tr>
							<td align="center">
								<input value="Previous" type="button" onClick="window.location='/cgi-bin/wiz_${PREVIOUS_PAGE}.sh?DocID=$DOC_ID'" tabindex="1">
							</td>
							<td align="center">
								<input value="Finish" type="submit" tabindex="2">
							</td>
							<td align="center">
								<input value="Cancel" type="button" onClick="window.location='/cgi-bin/wiz_cancel.sh?DocID=$DOC_ID'" tabindex="3">
							</td>
						</tr>
					</table>
				</form>
			</td></tr>
		</table>
	</body>
</html>
__HYLAFAX_HTML_EOF__
