#!/bin/bash
# Copyright 2007 Nabla.
# Distributed under the terms of the GNU General Public License v2
#

# prevent file globbing
set -f

function to_html()
{
	local s="$@"
	s=${s//&/&amp;}
	s=${s//\'/&apos;}
	s=${s//\"/&quot;}
	s=${s//</&lt;}
	s=${s//>/&gt;}
	echo $s
}

DOC_ID=`to_html $HYLAFAX_DocID`
JOB_ID=`to_html $HYLAFAX_JobID`
TITLE=`to_html $HYLAFAX_Title`
FAX_NUMBER=`to_html $HYLAFAX_FaxNumber`
ERROR_MSG=`to_html $HYLAFAX_ErrorMsg`

cat << __HYLAFAX_HTML_EOF__
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
	<head>
		<title>Send Fax Wizard - Recipient Information</title>
		<meta http-equiv="Content-Type" content="text/html; charset=utf-8">
		<link rel="stylesheet" type="text/css" href="/hylafax/templates/wiz.css" />
		<script type="text/javascript">
			var bFormInUse = false;
			function setInitialFocus()
			{
				if (!bFormInUse) {
					document.myForm.FaxNumber.focus();
				}
			}
			function ctrlOnFocus()
			{
				bFormInUse = true;
				document.myForm.FaxNumber.select();
			}
		</script>
	</head>
	<body onLoad="setInitialFocus()">
		<table>
			<tr><td>
				<table class="caption">
					<tr valign="center">
						<td valign="center">
							<h1 class="caption">Send Fax Wizard</h1>
						</td>
						<td align="left" valign="center">
							<img src="/hylafax/images/fax.gif" align="right">
						</td>
					</tr>
				</table>
                <hr>
			</td></tr>
			<tr><td>
                <table>
                    <tr>
                        <td><p class="doc_info_label">Job ID</p></td>
                        <td><p class="doc_info_data">$JOB_ID</p></td>
                    </tr>
                    <tr>
                        <td><p class="doc_info_label">Document:</p></td>
                        <td><p class="doc_info_data">$TITLE</p></td>
                    </tr>
                </table>
				<hr>
			</td></tr>
            <tr><td>
				<div class="form_error">
					<p><img src="/icons/warning16x16.png" hspace="5">Please check the following and try again:</p>
					<ul>
						<li>Please provide your fax number.</li>
					</ul>
				</div>
			</td></tr>
			<tr><td>
				<form name="myForm" action="/cgi-bin/wiz_cover_page.sh" method="post">
					<input type="hidden" name="DocID" value="$DOC_ID">
					<input type="hidden" name="ValidateForm" value="1">
					<h3 class="caption">Recipient information</h3>
					<p class="form_error">
					<label for="FaxNumber">Enter the fax number of the person you want to send fax to.</label><br>
__HYLAFAX_HTML_EOF__

if [ -z "$HYLAFAX_aHistory" ]; then

cat << __HYLAFAX_HTML_EOF__
					<input type="text" maxlength="13" name="FaxNumber" id="FaxNumber" value="$FAX_NUMBER" onFocus="ctrlOnFocus()" tabindex="1">
					<img src="/icons/warning16x16.png" hspace="5"><br>
					<span class="error_text">$ERROR_MSG</span>
__HYLAFAX_HTML_EOF__

else

cat << __HYLAFAX_HTML_EOF__
					<input type="radio" name="History" id="History" value="-1" checked>
					<input type="text" maxlength="13" name="FaxNumber" id="FaxNumber" value="$FAX_NUMBER" onFocus="ctrlOnFocus()" tabindex="1">
					<img src="/icons/warning16x16.png" hspace="5"><br>
					<span class="error_text">$ERROR_MSG</span>
					</p>
					<p>Or select below a fax number from one of your last entries:
__HYLAFAX_HTML_EOF__
	# import array hack (not yet supported by bash)
	eval "HYLAFAX_History=(${HYLAFAX_aHistory[*]})"
	count=${#HYLAFAX_History[@]}
	i=0
	while [ "$i" -lt "$count" ]; do
		fax=`to_html ${HYLAFAX_History[$i]}`
cat << __HYLAFAX_HTML_EOF__
					<br><input type="radio" name="History" id="History" value="$i">$fax
__HYLAFAX_HTML_EOF__
		i=`expr $i + 1`
	done

fi

cat << __HYLAFAX_HTML_EOF__	
					</p>
                	<hr>
					<table width="100%">
						<tr>
							<td align="center">
								<input value="Previous" type="button" onClick="window.location='/cgi-bin/wiz_general.sh?DocID=$DOC_ID'" tabindex="2">
							</td>
							<td align="center">
								<input value="Next" type="submit" tabindex="3">
							</td>
							<td align="center">
								<input value="Cancel" type="button" onClick="window.location='/cgi-bin/wiz_cancel.sh?DocID=$DOC_ID'" tabindex="4">
							</td>
						</tr>
					</table>
				</form>
			</td></tr>
		</table>
	</body>
</html>
__HYLAFAX_HTML_EOF__
